"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShadowPressable = void 0;
var _reactNativeSkia = require("@shopify/react-native-skia");
var _reactNativeReanimated = require("react-native-reanimated");
var _types = require("../types.js");
var _react = require("react");
var _utils = require("../utils.js");
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
const ShadowPressable = ({
  width: _width = 0,
  height: _height = 0,
  initialDepth = 3,
  shadowSpace = 6,
  shadowBlur = 10,
  shadowColor = _types.DEFAULT_SHADOW_COLOR,
  reflectedLightColor = _types.DEFAULT_REFLECTED_LIGHT_COLOR,
  duration = 200,
  damping = 0.8,
  isReflectedLightEnabled = true,
  ...props
}) => {
  const [boxSize, setBoxSize] = (0, _react.useState)({
    width: _width,
    height: _height
  });

  // Determine the final background color (pulling from `props.style` or a default).
  const backgroundColor = (0, _utils.getBackgroundColor)(props);
  const boxRadius = Number(props?.style ? props.style.borderRadius : 0) || 10;
  const depth = (0, _reactNativeReanimated.useSharedValue)(initialDepth);
  const offset = (0, _reactNativeReanimated.useDerivedValue)(() => Math.abs(depth.value));
  const rfOffset = (0, _reactNativeReanimated.useDerivedValue)(() => (0, _reactNativeReanimated.interpolate)(depth.value, [-initialDepth, initialDepth * damping], [-3, 3]));
  const inset = (0, _reactNativeReanimated.useDerivedValue)(() => depth.value <= 0);
  const blur = (0, _reactNativeReanimated.useDerivedValue)(() => (0, _reactNativeReanimated.interpolate)(Math.abs(depth.value), [shadowBlur, 0], [0, initialDepth * damping]));
  const onPressIn = () => {
    depth.value = (0, _reactNativeReanimated.withTiming)(-initialDepth * damping, {
      duration
    });
  };
  const onPressOut = () => {
    depth.value = (0, _reactNativeReanimated.withTiming)(initialDepth, {
      duration
    });
  };
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Pressable, {
    onLayout: ({
      nativeEvent: {
        layout: {
          width,
          height
        }
      }
    }) => setBoxSize({
      width,
      height
    }),
    ...props,
    style: [props.style, {
      backgroundColor: 'transparent'
    }],
    onPressIn: onPressIn,
    onPressOut: onPressOut,
    children: [boxSize.width === 0 && boxSize.height === 0 ? null : /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
      style: [props.style, styles.canvas, {
        width: boxSize.width,
        height: boxSize.height
      }],
      children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSkia.RoundedRect, {
        x: shadowSpace,
        y: shadowSpace,
        width: boxSize.width - shadowSpace * 2,
        height: boxSize.height - shadowSpace * 2,
        r: boxRadius,
        color: backgroundColor // The background fill of the rect
        ,
        children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: offset,
          dy: offset,
          blur: blur.value,
          color: shadowColor,
          inner: inset
        }), isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
          dx: rfOffset,
          dy: rfOffset,
          blur: blur,
          color: reflectedLightColor,
          inner: true
        })]
      })
    }), props.children]
  });
};
exports.ShadowPressable = ShadowPressable;
const styles = _reactNative.StyleSheet.create({
  canvas: {
    position: 'absolute',
    left: 0,
    top: 0,
    backgroundColor: 'transparent'
  }
});
//# sourceMappingURL=ShadowPressable.js.map